package com.adc.da.znks.controller;

import com.adc.da.znks.entity.Admin;
import com.adc.da.znks.entity.ResponseEntity;
import com.adc.da.znks.service.AdminService;
import com.adc.da.znks.util.GenResponse;
import com.adc.da.znks.vo.AdminSearch;
import com.adc.da.znks.vo.AdminVO;
import com.github.pagehelper.PageHelper;
import com.github.pagehelper.PageInfo;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.http.HttpStatus;
import org.springframework.web.bind.annotation.*;

import java.util.List;

@RestController
@RequestMapping("/api")
public class AdminController {

    @Autowired
    private AdminService adminService;

    @PostMapping("/admin")
    public ResponseEntity saveOne(Admin admin) {
        try {
            adminService.insertAdmin(admin);
            return GenResponse.success();
        } catch (Exception e) {
            return GenResponse.fail("保存失败");
        }
    }


    @PutMapping("/admin")
    public ResponseEntity updateOne(Admin admin) {
        try {
            adminService.updateAdmin(admin);
            return GenResponse.success();
        } catch (Exception e) {
            return GenResponse.fail("更新失败");
        }
    }


    @DeleteMapping("/admin/{adminId}")
    public ResponseEntity deleteOne(@PathVariable String adminId) {
        try {
            adminService.deleteAdmin(adminId);
            return GenResponse.success();
        } catch (Exception e) {
            return GenResponse.fail("删除失败");
        }
    }


    @GetMapping("/admin/{adminId}")
    public ResponseEntity<Admin> findOne(@PathVariable String adminId) {
        try {
            Admin admin = adminService.findAdmin(adminId);
            return GenResponse.success(String.valueOf(HttpStatus.OK.value()),
                    "查询成功", admin);
        } catch (Exception e) {
            return GenResponse.fail("查询失败");
        }
    }


    @GetMapping("/admin/page")
    public ResponseEntity<PageInfo> findByPage(AdminSearch adminSearch, @RequestParam(defaultValue = "1") Integer pageNum, @RequestParam(defaultValue = "8") Integer pageSize) {
        try {
            PageHelper.startPage(pageNum, pageSize);
            List<AdminVO> adminVOS = adminService.listAdminsByCondition(adminSearch, pageNum, pageSize);
            PageInfo<AdminVO> pageInfo = new PageInfo<AdminVO>(adminVOS);
            return GenResponse.success(String.valueOf(HttpStatus.OK.value()),
                    "查询成功", pageInfo);
        } catch (Exception e) {
            return GenResponse.fail("查询失败");
        }
    }


    @PostMapping("/admin/login")
    public ResponseEntity login(@RequestParam String adminName, @RequestParam String password) {
        try {
            if (adminService.login(adminName, password)) {
                return GenResponse.success(String.valueOf(HttpStatus.OK.value()),
                        "登录成功", true);
            } else {
                return GenResponse.fail("登录失败");
            }
        } catch (Exception e) {
            return GenResponse.fail("登录失败");
        }
    }


}
